OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "تختهٔ جدیدی به نام {board} ایجاد کردید",
    "{user} has created a new board {board}" : "{user} یک تخته جدیدی به نام {board} ایجاد کرد",
    "You have deleted the board {board}" : "تختهٔ {board} را حذف کردید",
    "{user} has deleted the board {board}" : "{user} تختهٔ {board} را حذف کرد",
    "You have restored the board {board}" : "تختهٔ {board} را بازیابی کردید",
    "{user} has restored the board {board}" : "{user} تختهٔ {board} را بازیابی کرد",
    "You have shared the board {board} with {acl}" : "تختهٔ {board} را با {acl} هم‌رسانی کردید",
    "{user} has shared the board {board} with {acl}" : "{user} تختهٔ {board} را با {acl} هم‌رسانی کرد",
    "You have removed {acl} from the board {board}" : "شما {acl} را از تختهٔ {board} حذف کردید",
    "{user} has removed {acl} from the board {board}" : "{user} اقدام به حذف {acl} از تختهٔ {board} کرد",
    "You have renamed the board {before} to {board}" : "نام تخته را از {before} به {board} تغییر دادید",
    "{user} has renamed the board {before} to {board}" : "{user} نام تخته را از {before} به {board} تغییر داد",
    "You have archived the board {board}" : "تختهٔ {board} را بایگانی کردید",
    "{user} has archived the board {before}" : "{user} تختهٔ {board} را بایگانی کرد",
    "You have unarchived the board {board}" : "تختهٔ {board} را از بایگانی خارج کردید",
    "{user} has unarchived the board {before}" : "{user} تختهٔ {board} را از بایگانی خارج کرد",
    "Personal" : "شخصی",
    "Finished" : "تمام شده",
    "To review" : "برای بازبینی",
    "Action needed" : "نیازمند اقدام",
    "Later" : "بعدا",
    "copy" : "کپی",
    "To do" : "برای انجام",
    "Doing" : "در حال انجام",
    "Done" : "انجام شد",
    "Example Task 3" : "نمونه کار ۳",
    "Example Task 2" : "نمونه کار ۲",
    "Example Task 1" : "نمونه کار ۱",
    "The file was uploaded" : "پرونده بارگذاری شد",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "حجم پرونده بارگذاری شده بیشتر از تنظیمات upload_max_filesize در پرونده php.ini است",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حداکثر حجم قابل بار گذاری از طریق HTML MAX_FILE_SIZE است",
    "The file was only partially uploaded" : "پرونده فقط به صورت جزئی و ناقص بارگذاری شد",
    "No file was uploaded" : "هیچ پرونده‌ای بارگذاری نشد",
    "Missing a temporary folder" : "یک پوشه موقت گم شده",
    "Could not write file to disk" : "عدم موفقیت در نوشتن پرونده روی حافظه",
    "A PHP extension stopped the file upload" : "یک افزونه پی‌اچ‌پی مانع بارگذاری پرونده شد",
    "No file uploaded or file size exceeds maximum of %s" : "پرونده‌ای بارگذاری نشد و یا حجم پرونده بیش از بیشینه مجاز %s بود",
    "Card details" : "جزئیات کارت",
    "Add board" : "تخته را اضافه کنید",
    "Select the board to link to a project" : "تخته‌ای را برای ایجاد پیوند با یک پروژه انتخاب کنید",
    "Search by board title" : "جستجو بر اساس عنوان تخته",
    "Select board" : "انتخاب تخته",
    "Select the card to link to a project" : "کارتی را برای ایجاد پیوند با یک پروژه انتخاب کنید",
    "Select a board" : "انتخاب یک تخته",
    "Select a card" : "انتخاب یک کارت",
    "Link to card" : "پیوند به کارت",
    "Cancel" : "لغو",
    "File already exists" : "پرونده از قبل موجود است",
    "A file with the name {filename} already exists." : "پرونده‌ای با نام {filename} از قبل موجود است.",
    "Do you want to overwrite it?" : "می‌خواهید روی آن بازنویسی شود؟",
    "Overwrite file" : "بازنویسی پرونده",
    "Keep existing file" : "پرونده موجود حفظ شود",
    "This board is read only" : "تخته، فقط خواندنی است",
    "Drop your files to upload" : "برای بارگذاری، پرونده‌ها را اینجا رها کنید",
    "Archived cards" : "کارت‌های بایگانی‌شده",
    "Add list" : "افزودن فهرست",
    "List name" : "نام فهرست",
    "Apply filter" : "اعمال پالایه",
    "Filter by tag" : "پالایش برحسب برچسب",
    "Overdue" : "تاریخ گذشته",
    "Next 24 hours" : "۲۴ ساعت آینده",
    "Next 7 days" : "۷ روز آینده",
    "Next 30 days" : "۳۰ روز آینده",
    "Clear filter" : "پاک کردن پالایه",
    "Show archived cards" : "نمایش کارت‌های بایگانی شده",
    "Toggle compact mode" : "تغییر حالت فشرده",
    "Details" : "جزئیات",
    "Loading board" : "بارکردن تخته",
    "Board not found" : "تخته یافت نشد",
    "Sharing" : "هم‌رسانی",
    "Tags" : "برچسب‌ها",
    "Deleted items" : "موارد حذف شده",
    "Timeline" : "خط زمانی",
    "Deleted lists" : "فهرست‌های پاک شده",
    "Undo" : "برگرداندن",
    "Deleted cards" : "کارت‌های پاک شده",
    "Share board with a user, group or circle …" : "هم‌رسانی تخته با کاربر، گروه یا حلقه...",
    "Board owner" : "مالک تخته",
    "(Group)" : "(گروه)",
    "(Circle)" : "(حلقه)",
    "Can edit" : "می‌تواند ویرایش کند",
    "Can share" : "می‌تواند هم‌رسانی کند",
    "Can manage" : "می‌تواند مدیریت کند",
    "Delete" : "حذف",
    "Delete list" : "حذف فهرست",
    "Add card" : "افزودن کارت",
    "Add a new card" : "افزودن یک کارت جدید",
    "Edit" : "ویرایش",
    "Add a new tag" : "افزودن یک برچسب جدید",
    "title and color value must be provided" : "نام و رنگ باید مشخص شود",
    "Title" : "عنوان",
    "Members" : "اعضا",
    "Upload attachment" : "بارگذاری پیوست",
    "Add this attachment" : "افزودن این پیوست",
    "Delete Attachment" : "حذف پیوست",
    "Restore Attachment" : "بازیابی پیوست",
    "Due date" : "موعد مقرر",
    "Description" : "توضیحات",
    "(Unsaved)" : "(ذخیره نشده)",
    "(Saving…)" : "(در حال ذخیره...)",
    "Formatting help" : "راهنمای قالب‌بندی",
    "Edit description" : "ویرایش توضیحات",
    "View description" : "نمایش توضیحات",
    "Add Attachment" : "افزودن پیوست",
    "Attachments" : "پیوست‌ها",
    "Comments" : "نظرات",
    "Choose attachment" : "انتخاب پیوست",
    "Select Date" : "تاریخ را انتخاب کنید",
    "Modified" : "تغییر یافته",
    "Created" : "ایجاد شده",
    "No comments yet. Begin the discussion!" : "هنوز نظری وجود ندارد. بحثی را آغاز کنید!",
    "Save" : "ذخیره",
    "The comment cannot be empty." : "نظر نمی‌تواند خالی باشد.",
    "The comment cannot be longer than 1000 characters." : "نظر نمی‌تواند طولانی‌تر از ۱۰۰۰ حرف باشد.",
    "In reply to" : "در پاسخ به",
    "Reply" : "پاسخ",
    "Update" : "به‌روزرسانی",
    "(group)" : "(گروه)",
    "(circle)" : "(حلقه)",
    "Archive card" : "کارت بایگانی",
    "Delete card" : "حذف کارت",
    "Move card" : "انتقال کارت",
    "Move card to another board" : "انتقال کارت به تخته‌ای دیگر",
    "seconds ago" : "ثانیه‌هایی پیش",
    "All boards" : "همه تخته‌ها",
    "Archived boards" : "تخته‌های بایگانی شده",
    "Shared with you" : "با شما به اشتراک گذاشته شده است",
    "Edit board" : "ویرایش تخته",
    "An error occurred" : "خطایی روی داد",
    "Today" : "Today",
    "Tomorrow" : "فردا",
    "This week" : "این هفته"
},
"nplurals=2; plural=(n > 1);");
